@@ -2,8 +2,13 @@ from __future__ import annotations
 from dataclasses import dataclass, field
 from typing import TypedDict, Tuple
 
-from spacepackets.cfdp.definitions import FileSize, TransmissionModes, CrcFlag, \
-    SegmentationControl, Direction
+from spacepackets.cfdp.definitions import (
+    FileSize,
+    TransmissionModes,
+    CrcFlag,
+    SegmentationControl,
+    Direction,
+)
 from spacepackets.log import get_console_logger
 
 
@@ -15,12 +20,15 @@ class PduConfig:
     determine the flag values of the respective fields from the global confiuration to avoid
     specifying parameter which rarely change repeatedly
     """
+
     transaction_seq_num: bytes
     trans_mode: TransmissionModes
     file_size: FileSize = FileSize.GLOBAL_CONFIG
     crc_flag: CrcFlag = CrcFlag.GLOBAL_CONFIG
     direction: Direction = Direction.TOWARDS_RECEIVER
-    seg_ctrl: SegmentationControl = SegmentationControl.NO_RECORD_BOUNDARIES_PRESERVATION
+    seg_ctrl: SegmentationControl = (
+        SegmentationControl.NO_RECORD_BOUNDARIES_PRESERVATION
+    )
     source_entity_id: bytes = bytes()
     dest_entity_id: bytes = bytes()
 
@@ -32,7 +40,7 @@ class PduConfig:
             source_entity_id=bytes([0]),
             dest_entity_id=bytes([0]),
             file_size=FileSize.GLOBAL_CONFIG,
-            crc_flag=CrcFlag.GLOBAL_CONFIG
+            crc_flag=CrcFlag.GLOBAL_CONFIG,
         )
 
     def __post_init__(self):
@@ -51,38 +59,40 @@ class CfdpDict(TypedDict):
 
 # TODO: Protect dict access with a dedicated lock for thread-safety
 __CFDP_DICT: CfdpDict = {
-    'source_dest_entity_ids': (bytes(), bytes()),
-    'with_crc': CrcFlag.NO_CRC,
-    'file_size': FileSize.NORMAL,
+    "source_dest_entity_ids": (bytes(), bytes()),
+    "with_crc": CrcFlag.NO_CRC,
+    "file_size": FileSize.NORMAL,
 }
 
 
 def set_default_pdu_crc_mode(with_crc: CrcFlag):
-    __CFDP_DICT['with_crc'] = with_crc
+    __CFDP_DICT["with_crc"] = with_crc
 
 
 def get_default_pdu_crc_mode() -> CrcFlag:
-    return __CFDP_DICT['with_crc']
+    return __CFDP_DICT["with_crc"]
 
 
 def set_entity_ids(source_entity_id: bytes, dest_entity_id: bytes):
-    __CFDP_DICT['source_dest_entity_ids'] = (source_entity_id, dest_entity_id)
+    __CFDP_DICT["source_dest_entity_ids"] = (source_entity_id, dest_entity_id)
 
 
 def get_entity_ids() -> Tuple[bytes, bytes]:
     """Return a tuple where the first entry is the source entity ID"""
-    return __CFDP_DICT['source_dest_entity_ids']
+    return __CFDP_DICT["source_dest_entity_ids"]
 
 
 def set_default_file_size(file_size: FileSize):
-    __CFDP_DICT['file_size'] = file_size
+    __CFDP_DICT["file_size"] = file_size
 
 
 def get_default_file_size() -> FileSize:
-    return __CFDP_DICT['file_size']
+    return __CFDP_DICT["file_size"]
 
 
-def check_packet_length(raw_packet_len: int, min_len: int, warn_on_fail: bool = True) -> bool:
+def check_packet_length(
+    raw_packet_len: int, min_len: int, warn_on_fail: bool = True
+) -> bool:
     """Check whether the length of a raw packet is shorter than a specified expected minimum length.
     By defaults, prints a warning if this is the case
     :param raw_packet_len:
@@ -95,7 +105,7 @@ def check_packet_length(raw_packet_len: int, min_len: int, warn_on_fail: bool =
         if warn_on_fail:
             logger = get_console_logger()
             logger.warning(
-                f'Detected packet length {raw_packet_len}, smaller than expected {min_len}'
+                f"Detected packet length {raw_packet_len}, smaller than expected {min_len}"
             )
         return False
     return True
