@@ -1,5 +1,5 @@
 from .header import PduHeader, PduType, SegmentMetadataFlag
-from .file_directive import FileDirectivePduBase, ConditionCode, DirectiveCodes, IsFileDirective
+from .file_directive import FileDirectivePduBase, DirectiveCodes, IsFileDirective
 from .ack import TransactionStatus, AckPdu
 from .eof import EofPdu
 from .finished import FinishedPdu
