@@ -8,6 +8,7 @@ from spacepackets.cfdp.definitions import ConditionCode
 
 class TlvTypes(enum.IntEnum):
     """All available TLV types"""
+
     FILESTORE_REQUEST = 0x00
     FILESTORE_RESPONSE = 0x01
     MESSAGE_TO_USER = 0x02
@@ -19,6 +20,7 @@ class TlvTypes(enum.IntEnum):
 class FilestoreActionCode(enum.IntEnum):
     """All filestore action codes as specified in CCSDS 727.0-B-5 p.86
     SNP: Second name present, SNN: Second name not present"""
+
     CREATE_FILE_SNM = 0b0000
     DELETE_FILE_SNN = 0b0001
     RENAME_FILE_SNP = 0b0010
@@ -33,74 +35,85 @@ class FilestoreActionCode(enum.IntEnum):
 class FilestoreResponseStatusCode(enum.IntEnum):
     """File store response status codes. First four bits are the action code, last four bits
     the status code"""
-    _SUCCESS = 0b0000
-    _NOT_PERFORMED = 0b1111
 
-    CREATE_SUCCESS = FilestoreActionCode.CREATE_FILE_SNM << 4 | _SUCCESS
+    SUCCESS = 0b0000
+    NOT_PERFORMED = 0b1111
+    # Offsets past the size of the file are not supported for the copy procedure for now
+    APPEND_FROM_DATA_INVALID_OFFSET = 0b0001
+    APPEND_FROM_DATA_FILE_NOT_EXISTS = 0b0010
+
+    CREATE_SUCCESS = FilestoreActionCode.CREATE_FILE_SNM << 4 | SUCCESS
     CREATE_NOT_ALLOWED = FilestoreActionCode.CREATE_FILE_SNM << 4 | 0b0001
-    CREATE_NOT_PERFORMED = FilestoreActionCode.CREATE_FILE_SNM << 4 | _NOT_PERFORMED
+    CREATE_NOT_PERFORMED = FilestoreActionCode.CREATE_FILE_SNM << 4 | NOT_PERFORMED
 
-    DELETE_SUCCESS = FilestoreActionCode.DELETE_FILE_SNN << 4 | _SUCCESS
+    DELETE_SUCCESS = FilestoreActionCode.DELETE_FILE_SNN << 4 | SUCCESS
     DELETE_FILE_DOES_NOT_EXIST = FilestoreActionCode.DELETE_FILE_SNN << 4 | 0b0001
-    DELETE_NOT_ALLOWED = FilestoreActionCode.DELETE_FILE_SNN << 4 | _NOT_PERFORMED
+    DELETE_NOT_ALLOWED = FilestoreActionCode.DELETE_FILE_SNN << 4 | NOT_PERFORMED
 
-    RENAME_SUCCESS = FilestoreActionCode.RENAME_FILE_SNP << 4 | _SUCCESS
+    RENAME_SUCCESS = FilestoreActionCode.RENAME_FILE_SNP << 4 | SUCCESS
     RENAME_OLD_FILE_DOES_NOT_EXIST = FilestoreActionCode.RENAME_FILE_SNP << 4 | 0b0001
     RENAME_NEW_FILE_DOES_EXIST = FilestoreActionCode.RENAME_FILE_SNP << 4 | 0b0010
     RENAME_NOT_ALLOWED = FilestoreActionCode.RENAME_FILE_SNP << 4 | 0b0011
-    RENAME_NOT_PERFORMED = FilestoreActionCode.RENAME_FILE_SNP << 4 | _NOT_PERFORMED
+    RENAME_NOT_PERFORMED = FilestoreActionCode.RENAME_FILE_SNP << 4 | NOT_PERFORMED
 
-    APPEND_SUCCESS = FilestoreActionCode.APPEND_FILE_SNP << 4 | _SUCCESS
+    APPEND_SUCCESS = FilestoreActionCode.APPEND_FILE_SNP << 4 | SUCCESS
+    # Name of file whose contents form the first part of the new file and name of the new file
     APPEND_FILE_NAME_ONE_NOT_EXISTS = FilestoreActionCode.APPEND_FILE_SNP << 4 | 0b0001
+    # Name of the file whose contents will form the second part of the new file
     APPEND_FILE_NAME_TWO_NOT_EXISTS = FilestoreActionCode.APPEND_FILE_SNP << 4 | 0b0010
     APPEND_NOT_ALLOWED = FilestoreActionCode.APPEND_FILE_SNP << 4 | 0b0011
-    APPEND_NOT_PERFORMED = FilestoreActionCode.APPEND_FILE_SNP << 4 | _NOT_PERFORMED
+    APPEND_NOT_PERFORMED = FilestoreActionCode.APPEND_FILE_SNP << 4 | NOT_PERFORMED
 
-    REPLACE_SUCCESS = FilestoreActionCode.REPLACE_FILE_SNP << 4 | _SUCCESS
-    REPLACE_FILE_NAME_ONE_DOES_NOT_EXIST = FilestoreActionCode.REPLACE_FILE_SNP << 4 | 0b0001
-    REPLACE_FILE_NAME_TWO_DOES_NOT_EXIST = FilestoreActionCode.REPLACE_FILE_SNP << 4 | 0b0010
+    REPLACE_SUCCESS = FilestoreActionCode.REPLACE_FILE_SNP << 4 | SUCCESS
+    # File name
+    REPLACE_FILE_NAME_ONE_TO_BE_REPLACED_DOES_NOT_EXIST = (
+        FilestoreActionCode.REPLACE_FILE_SNP << 4 | 0b0001
+    )
+    REPLACE_FILE_NAME_TWO_REPLACE_SOURCE_NOT_EXIST = (
+        FilestoreActionCode.REPLACE_FILE_SNP << 4 | 0b0010
+    )
     REPLACE_NOT_ALLOWED = FilestoreActionCode.REPLACE_FILE_SNP << 4 | 0b0011
-    REPLACE_NOT_PERFORMED = FilestoreActionCode.REPLACE_FILE_SNP << 4 | _NOT_PERFORMED
+    REPLACE_NOT_PERFORMED = FilestoreActionCode.REPLACE_FILE_SNP << 4 | NOT_PERFORMED
 
-    CREATE_DIR_SUCCESS = FilestoreActionCode.CREATE_DIR_SNN << 4 | _SUCCESS
+    CREATE_DIR_SUCCESS = FilestoreActionCode.CREATE_DIR_SNN << 4 | SUCCESS
     CREATE_DIR_CAN_NOT_BE_CREATED = FilestoreActionCode.CREATE_DIR_SNN << 4 | 0b0001
-    CREATE_DIR_NOT_PERFORMED = FilestoreActionCode.CREATE_DIR_SNN << 4 | _NOT_PERFORMED
+    CREATE_DIR_NOT_PERFORMED = FilestoreActionCode.CREATE_DIR_SNN << 4 | NOT_PERFORMED
 
-    REMOVE_DIR_SUCCESS = FilestoreActionCode.REMOVE_DIR_SNN << 4 | _SUCCESS
+    REMOVE_DIR_SUCCESS = FilestoreActionCode.REMOVE_DIR_SNN << 4 | SUCCESS
     REMOVE_DIR_DOES_NOT_EXIST = FilestoreActionCode.REMOVE_DIR_SNN << 4 | 0b0001
     REMOVE_DIR_NOT_ALLOWED = FilestoreActionCode.REMOVE_DIR_SNN << 4 | 0b0010
-    REMOVE_DIR_NOT_PERFORMED = FilestoreActionCode.REMOVE_DIR_SNN << 4 | _NOT_PERFORMED
+    REMOVE_DIR_NOT_PERFORMED = FilestoreActionCode.REMOVE_DIR_SNN << 4 | NOT_PERFORMED
 
-    DENY_FILE_DEL_SUCCESS = FilestoreActionCode.DENY_FILE_SMM << 4 | _SUCCESS
+    DENY_FILE_DEL_SUCCESS = FilestoreActionCode.DENY_FILE_SMM << 4 | SUCCESS
     DENY_FILE_DEL_NOT_ALLOWED = FilestoreActionCode.DENY_FILE_SMM << 4 | 0b0010
-    DENY_FILE_DEL_NOT_PERFORMED = FilestoreActionCode.DENY_FILE_SMM << 4 | _NOT_PERFORMED
+    DENY_FILE_DEL_NOT_PERFORMED = FilestoreActionCode.DENY_FILE_SMM << 4 | NOT_PERFORMED
 
-    DENY_DIR_DEL_SUCCESS = FilestoreActionCode.DENY_DIR_SNN << 4 | _SUCCESS
+    DENY_DIR_DEL_SUCCESS = FilestoreActionCode.DENY_DIR_SNN << 4 | SUCCESS
     DENY_DIR_DEL_NOT_ALLOWED = FilestoreActionCode.DENY_DIR_SNN << 4 | 0b0010
-    DENY_DIR_DEL_NOT_PERFORMED = FilestoreActionCode.DENY_DIR_SNN << 4 | _NOT_PERFORMED
+    DENY_DIR_DEL_NOT_PERFORMED = FilestoreActionCode.DENY_DIR_SNN << 4 | NOT_PERFORMED
     INVALID = -1
 
 
 def map_enum_status_code_to_int(status_code: FilestoreResponseStatusCode) -> int:
-    return status_code & 0x0f
+    return status_code & 0x0F
 
 
 def map_enum_status_code_to_action_status_code(
-        status_code_enum: FilestoreResponseStatusCode
+    status_code_enum: FilestoreResponseStatusCode,
 ) -> Tuple[FilestoreActionCode, int]:
     """Map a given file store response status code to the action code and the corresponding
     4 bit status code. the status code will be 0x00 for a SUCCESS operation and 0b1111 if the
     operation was not performed"""
     try:
-        status_code = FilestoreActionCode((status_code_enum & 0xf0) >> 4)
+        status_code = FilestoreActionCode((status_code_enum & 0xF0) >> 4)
     except ValueError:
         # Invalid status code
         status_code = -1
-    return status_code, status_code_enum & 0x0f
+    return status_code, status_code_enum & 0x0F
 
 
 def map_int_status_code_to_enum(
-        action_code: FilestoreActionCode, status_code: int
+    action_code: FilestoreActionCode, status_code: int
 ) -> FilestoreResponseStatusCode:
     """Maps an action code and the status code of a filestore response to the status code.
 
@@ -120,13 +133,10 @@ class CfdpTlv:
     """Encapsulates the CFDP TLV (type-length-value) format.
     For more information, refer to CCSDS 727.0-B-5 p.77
     """
+
     MINIMAL_LEN = 2
 
-    def __init__(
-            self,
-            tlv_type: TlvTypes,
-            value: bytes
-    ):
+    def __init__(self, tlv_type: TlvTypes, value: bytes):
         """Constructor for TLV field.
 
         :param tlv_type:
@@ -136,7 +146,7 @@ class CfdpTlv:
         self.length = len(value)
         if self.length > 255:
             logger = get_console_logger()
-            logger.warning('Length larger than allowed 255 bytes')
+            logger.warning("Length larger than allowed 255 bytes")
             raise ValueError
         self.tlv_type = tlv_type
         self.value = value
@@ -158,14 +168,14 @@ class CfdpTlv:
         """
         if len(raw_bytes) < 2:
             logger = get_console_logger()
-            logger.warning('Invalid length for TLV field, less than 2')
+            logger.warning("Invalid length for TLV field, less than 2")
             raise ValueError
         try:
             tlv_type = TlvTypes(raw_bytes[0])
         except ValueError:
             logger = get_console_logger()
             logger.warning(
-                f'TLV field invalid, found value {raw_bytes[0]} is not a possible TLV parameter'
+                f"TLV field invalid, found value {raw_bytes[0]} is not a possible TLV parameter"
             )
             raise ValueError
 
@@ -174,13 +184,10 @@ class CfdpTlv:
             length = raw_bytes[1]
             if 2 + length > len(raw_bytes):
                 logger = get_console_logger()
-                logger.warning(f'Detected TLV length exceeds size of passed bytearray')
+                logger.warning(f"Detected TLV length exceeds size of passed bytearray")
                 raise ValueError
-            value.extend(raw_bytes[2: 2 + length])
-        return cls(
-            tlv_type=tlv_type,
-            value=value
-        )
+            value.extend(raw_bytes[2 : 2 + length])
+        return cls(tlv_type=tlv_type, value=value)
 
     @property
     def packet_len(self) -> int:
@@ -210,9 +217,7 @@ class EntityIdTlv(ConcreteTlvBase):
 
     @classmethod
     def __empty(cls) -> EntityIdTlv:
-        return cls(
-            entity_id=bytes()
-        )
+        return cls(entity_id=bytes())
 
     @classmethod
     def unpack(cls, raw_bytes: bytes) -> EntityIdTlv:
@@ -239,22 +244,21 @@ class FaultHandlerOverrideHandlerCodes(enum.IntEnum):
 
 class FaultHandlerOverrideTlv(ConcreteTlvBase):
     def __init__(
-            self, condition_code: ConditionCode, handler_code: FaultHandlerOverrideHandlerCodes
+        self,
+        condition_code: ConditionCode,
+        handler_code: FaultHandlerOverrideHandlerCodes,
     ):
         self.condition_code = condition_code
         self.handler_code = handler_code
         tlv_value = bytes([(self.condition_code << 4) | self.handler_code])
-        tlv = CfdpTlv(
-            tlv_type=TlvTypes.FAULT_HANDLER,
-            value=tlv_value
-        )
+        tlv = CfdpTlv(tlv_type=TlvTypes.FAULT_HANDLER, value=tlv_value)
         ConcreteTlvBase.__init__(self, tlv=tlv)
 
     @classmethod
     def __empty(cls) -> FaultHandlerOverrideTlv:
         return cls(
             condition_code=ConditionCode.NO_ERROR,
-            handler_code=FaultHandlerOverrideHandlerCodes.IGNORE_ERROR
+            handler_code=FaultHandlerOverrideHandlerCodes.IGNORE_ERROR,
         )
 
     @classmethod
@@ -262,8 +266,10 @@ class FaultHandlerOverrideTlv(ConcreteTlvBase):
         fault_handler_ovr_tlv = cls.__empty()
         fault_handler_ovr_tlv.tlv = CfdpTlv.unpack(raw_bytes=raw_bytes)
         fault_handler_ovr_tlv._check_type(tlv_type=TlvTypes.FAULT_HANDLER)
-        fault_handler_ovr_tlv.condition_code = (fault_handler_ovr_tlv.tlv.value[0] & 0xf0) >> 4
-        fault_handler_ovr_tlv.handler_code = fault_handler_ovr_tlv.tlv.value[0] & 0x0f
+        fault_handler_ovr_tlv.condition_code = (
+            fault_handler_ovr_tlv.tlv.value[0] & 0xF0
+        ) >> 4
+        fault_handler_ovr_tlv.handler_code = fault_handler_ovr_tlv.tlv.value[0] & 0x0F
         return fault_handler_ovr_tlv
 
     @classmethod
@@ -278,19 +284,16 @@ class FaultHandlerOverrideTlv(ConcreteTlvBase):
 def create_cfdp_proxy_and_dir_op_message_marker() -> bytes:
     """CCSDS 727.0-B-5 p.88: The message identifier for standard CFDP proxy and dir op messages
     is the presence of the ASCII characters 'cfdp' in the first four octests of each message"""
-    return 'cfdp'.encode()
+    return "cfdp".encode()
 
 
 class MessageToUserTlv(ConcreteTlvBase):
     def __init__(self, value: bytes):
-        tlv = CfdpTlv(
-            tlv_type=TlvTypes.MESSAGE_TO_USER,
-            value=value
-        )
+        tlv = CfdpTlv(tlv_type=TlvTypes.MESSAGE_TO_USER, value=value)
         ConcreteTlvBase.__init__(self, tlv=tlv)
 
     def is_standard_proxy_dir_ops_msg(self) -> bool:
-        if len(self.tlv.value) >= 4 and self.tlv.value[0:4].decode() == 'cfdp':
+        if len(self.tlv.value) >= 4 and self.tlv.value[0:4].decode() == "cfdp":
             return True
         return False
 
@@ -316,10 +319,7 @@ class MessageToUserTlv(ConcreteTlvBase):
 
 class FlowLabelTlv(ConcreteTlvBase):
     def __init__(self, value: bytes):
-        tlv = CfdpTlv(
-            tlv_type=TlvTypes.FLOW_LABEL,
-            value=value
-        )
+        tlv = CfdpTlv(tlv_type=TlvTypes.FLOW_LABEL, value=value)
         ConcreteTlvBase.__init__(self, tlv=tlv)
 
     @classmethod
@@ -343,10 +343,10 @@ class FlowLabelTlv(ConcreteTlvBase):
 
 class FileStoreRequestBase:
     def __init__(
-            self,
-            action_code: FilestoreActionCode,
-            first_file_name: str,
-            second_file_name: str
+        self,
+        action_code: FilestoreActionCode,
+        first_file_name: str,
+        second_file_name: str,
     ):
         self.action_code = action_code
         self.first_file_name = first_file_name
@@ -355,23 +355,20 @@ class FileStoreRequestBase:
     def _common_packer(self, status_code: int) -> bytearray:
         tlv_value = bytearray()
         tlv_value.append(self.action_code << 4 | status_code)
-        first_name_lv = CfdpLv(
-            value=self.first_file_name.encode()
-        )
+        first_name_lv = CfdpLv(value=self.first_file_name.encode())
         tlv_value.extend(first_name_lv.pack())
         if self.action_code in [
-            FilestoreActionCode.REPLACE_FILE_SNP, FilestoreActionCode.RENAME_FILE_SNP,
-            FilestoreActionCode.APPEND_FILE_SNP
+            FilestoreActionCode.REPLACE_FILE_SNP,
+            FilestoreActionCode.RENAME_FILE_SNP,
+            FilestoreActionCode.APPEND_FILE_SNP,
         ]:
-            second_name_lv = CfdpLv(
-                value=self.second_file_name.encode()
-            )
+            second_name_lv = CfdpLv(value=self.second_file_name.encode())
             tlv_value.extend(second_name_lv.pack())
         return tlv_value
 
     @staticmethod
     def _common_unpacker(
-            raw_bytes: bytes, expected_tlv_type: TlvTypes
+        raw_bytes: bytes, expected_tlv_type: TlvTypes
     ) -> Tuple[FilestoreActionCode, str, int, int, Optional[str]]:
         """Does only unpack common fields, does not unpack the filestore message of a Filestore
         Response package
@@ -383,46 +380,53 @@ class FileStoreRequestBase:
         tlv = CfdpTlv.unpack(raw_bytes=raw_bytes)
         if tlv.tlv_type != expected_tlv_type:
             logger = get_console_logger()
-            logger.warning('Invalid TLV type detected')
+            logger.warning("Invalid TLV type detected")
             raise ValueError
         value_idx = 0
-        action_code_as_int = (tlv.value[value_idx] & 0xf0) >> 4
+        action_code_as_int = (tlv.value[value_idx] & 0xF0) >> 4
         try:
             action_code = FilestoreActionCode(action_code_as_int)
         except ValueError:
             logger = get_console_logger()
             logger.warning(
-                f'Invalid action code in file store response with value {action_code_as_int}'
+                f"Invalid action code in file store response with value {action_code_as_int}"
             )
             raise ValueError
-        status_code_as_int = tlv.value[value_idx] & 0x0f
+        status_code_as_int = tlv.value[value_idx] & 0x0F
         value_idx += 1
         first_lv = CfdpLv.unpack(raw_bytes=tlv.value[value_idx:])
         value_idx += first_lv.packet_len
         first_file_name = first_lv.value.decode()
         if action_code in [
-            FilestoreActionCode.REPLACE_FILE_SNP, FilestoreActionCode.RENAME_FILE_SNP,
-            FilestoreActionCode.APPEND_FILE_SNP
+            FilestoreActionCode.REPLACE_FILE_SNP,
+            FilestoreActionCode.RENAME_FILE_SNP,
+            FilestoreActionCode.APPEND_FILE_SNP,
         ]:
             second_lv = CfdpLv.unpack(raw_bytes=tlv.value[value_idx:])
             value_idx += second_lv.packet_len
             second_file_name = second_lv.value.decode()
         else:
             second_file_name = None
-        return action_code, first_file_name, status_code_as_int, tlv.packet_len, second_file_name
+        return (
+            action_code,
+            first_file_name,
+            status_code_as_int,
+            tlv.packet_len,
+            second_file_name,
+        )
 
 
 class FileStoreRequestTlv(FileStoreRequestBase, ConcreteTlvBase):
     def __init__(
-            self,
-            action_code: FilestoreActionCode,
-            first_file_name: str,
-            second_file_name: str = ""
+        self,
+        action_code: FilestoreActionCode,
+        first_file_name: str,
+        second_file_name: str = "",
     ):
         super().__init__(
             action_code=action_code,
             first_file_name=first_file_name,
-            second_file_name=second_file_name
+            second_file_name=second_file_name,
         )
         tlv = self._build_tlv()
         ConcreteTlvBase.__init__(self, tlv=tlv)
@@ -432,15 +436,12 @@ class FileStoreRequestTlv(FileStoreRequestBase, ConcreteTlvBase):
         return cls(
             action_code=FilestoreActionCode.CREATE_FILE_SNM,
             first_file_name="",
-            second_file_name=""
+            second_file_name="",
         )
 
     def _build_tlv(self) -> CfdpTlv:
         tlv_value = self._common_packer(status_code=0b0000)
-        return CfdpTlv(
-            tlv_type=TlvTypes.FILESTORE_REQUEST,
-            value=tlv_value
-        )
+        return CfdpTlv(tlv_type=TlvTypes.FILESTORE_REQUEST, value=tlv_value)
 
     @classmethod
     def unpack(cls, raw_bytes: bytearray) -> FileStoreRequestTlv:
@@ -466,17 +467,17 @@ class FileStoreRequestTlv(FileStoreRequestBase, ConcreteTlvBase):
 
 class FileStoreResponseTlv(FileStoreRequestBase, ConcreteTlvBase):
     def __init__(
-            self,
-            action_code: FilestoreActionCode,
-            status_code: FilestoreResponseStatusCode,
-            first_file_name: str,
-            second_file_name: str = "",
-            filestore_msg: CfdpLv = CfdpLv(value=bytes())
+        self,
+        action_code: FilestoreActionCode,
+        status_code: FilestoreResponseStatusCode,
+        first_file_name: str,
+        second_file_name: str = "",
+        filestore_msg: CfdpLv = CfdpLv(value=bytes()),
     ):
         super().__init__(
             action_code=action_code,
             first_file_name=first_file_name,
-            second_file_name=second_file_name
+            second_file_name=second_file_name,
         )
         self.status_code = status_code
         self.filestore_msg = filestore_msg
@@ -489,17 +490,14 @@ class FileStoreResponseTlv(FileStoreRequestBase, ConcreteTlvBase):
             action_code=FilestoreActionCode.CREATE_FILE_SNM,
             status_code=FilestoreResponseStatusCode.CREATE_SUCCESS,
             first_file_name="",
-            second_file_name=""
+            second_file_name="",
         )
 
     def _build_tlv(self) -> CfdpTlv:
         status_code_as_int = map_enum_status_code_to_int(status_code=self.status_code)
         tlv_value = self._common_packer(status_code=status_code_as_int)
         tlv_value.extend(self.filestore_msg.pack())
-        return CfdpTlv(
-            tlv_type=TlvTypes.FILESTORE_RESPONSE,
-            value=tlv_value
-        )
+        return CfdpTlv(tlv_type=TlvTypes.FILESTORE_RESPONSE, value=tlv_value)
 
     @classmethod
     def unpack(cls, raw_bytes: bytearray) -> FileStoreResponseTlv:
@@ -510,18 +508,20 @@ class FileStoreResponseTlv(FileStoreRequestBase, ConcreteTlvBase):
         filestore_reply.action_code = action_code
         filestore_reply.first_file_name = first_name
         try:
-            status_code_named = FilestoreResponseStatusCode(action_code << 4 | status_code)
+            status_code_named = FilestoreResponseStatusCode(
+                action_code << 4 | status_code
+            )
         except ValueError:
             logger = get_console_logger()
             logger.warning(
-                f'Invalid status code in file store response with value {status_code} for '
-                f'action code {action_code}'
+                f"Invalid status code in file store response with value {status_code} for "
+                f"action code {action_code}"
             )
             raise ValueError
         filestore_reply.status_code = status_code_named
         if second_name is not None:
             filestore_reply.second_file_name = second_name
-        filestore_reply.filestore_msg = CfdpLv.unpack(raw_bytes=raw_bytes[idx - 1:])
+        filestore_reply.filestore_msg = CfdpLv.unpack(raw_bytes=raw_bytes[idx - 1 :])
         filestore_reply.tlv = filestore_reply._build_tlv()
         return filestore_reply
 
@@ -534,11 +534,13 @@ class FileStoreResponseTlv(FileStoreRequestBase, ConcreteTlvBase):
         return file_store_response_tlv
 
 
-TlvBase = TypeVar('TlvBase', bound=ConcreteTlvBase)
+TlvBase = TypeVar("TlvBase", bound=ConcreteTlvBase)
 TlvList = List[Union[CfdpTlv, TlvBase]]
 
 
-def concrete_tlv_factory(cfdp_tlv: CfdpTlv, _tlv_type: Type[TlvBase] = TlvBase) -> TlvBase:
+def concrete_tlv_factory(
+    cfdp_tlv: CfdpTlv, _tlv_type: Type[TlvBase] = TlvBase
+) -> TlvBase:
     """This factory returns the concrete CFDP TLV class from a generic CFDP TLV.
 
     Please note that this might not be the most efficient way to create the concrete classes and
