@@ -6,10 +6,17 @@ from spacepackets.ecss.tm import CdsShortTimestamp, PusVersion, PusTelemetry
 
 class Service17TM:
     def __init__(
-            self, subservice: int, time: CdsShortTimestamp = None, ssc: int = 0,
-            source_data: bytearray = bytearray([]), apid: int = -1, packet_version: int = 0b000,
-            pus_version: PusVersion = PusVersion.GLOBAL_CONFIG, secondary_header_flag: bool = True,
-            space_time_ref: int = 0b0000, destination_id: int = 0
+        self,
+        subservice: int,
+        time: CdsShortTimestamp = None,
+        ssc: int = 0,
+        source_data: bytearray = bytearray([]),
+        apid: int = -1,
+        packet_version: int = 0b000,
+        pus_version: PusVersion = PusVersion.GLOBAL_CONFIG,
+        secondary_header_flag: bool = True,
+        space_time_ref: int = 0b0000,
+        destination_id: int = 0,
     ):
         self.pus_tm = PusTelemetry(
             service=PusServices.SERVICE_17_TEST,
@@ -22,7 +29,7 @@ class Service17TM:
             pus_version=pus_version,
             secondary_header_flag=secondary_header_flag,
             space_time_ref=space_time_ref,
-            destination_id=destination_id
+            destination_id=destination_id,
         )
 
     def pack(self) -> bytearray:
@@ -30,13 +37,13 @@ class Service17TM:
 
     @classmethod
     def __empty(cls) -> Service17TM:
-        return cls(
-            subservice=0
-        )
+        return cls(subservice=0)
 
     @classmethod
     def unpack(
-            cls, raw_telemetry: bytearray, pus_version: PusVersion = PusVersion.GLOBAL_CONFIG
+        cls,
+        raw_telemetry: bytearray,
+        pus_version: PusVersion = PusVersion.GLOBAL_CONFIG,
     ) -> Service17TM:
         service_17_tm = cls.__empty()
         service_17_tm.pus_tm = PusTelemetry.unpack(
